Learn R Programming

eqn2svg (version 0.1.0)

l_time_domain: Laplace Transforms

Description

The datasets l_time_domain and l_laplace_s_domain provide Laplace transforms for many common functions of a single variable. Taken as a pair of equal-length vectors, the LaTeX formulas within each index position represent a common function, where any instance within the l_time_domain vector that function in the time domain, and, the corresponding Laplace s-domain function exists in the l_laplace_s_domain vector.

Usage

l_time_domain

Arguments

Format

An object of class character of length 37.